"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Window.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import EvtHandler
import Parameters as wx

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class Window(EvtHandler):
    """"""

    def __init__(self, parent, id, pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=0, name=wx.PyPanelNameStr):
        """"""
        pass

    def AcceptsFocus(self):
        """"""
        pass

    def AddChild(self, child):
        """"""
        pass

    def CaptureMouse(self):
        """"""
        pass

    def Center(self, direction=wx.BOTH):
        """"""
        pass

    def CenterOnParent(self, direction=wx.BOTH):
        """"""
        pass

    def CenterOnScreen(self, direction=wx.BOTH):
        """"""
        pass

    def Centre(self, direction=wx.BOTH):
        """"""
        pass

    def CentreOnParent(self, direction=wx.BOTH):
        """"""
        pass

    def CentreOnScreen(self, direction=wx.BOTH):
        """"""
        pass

    def Clear(self):
        """"""
        pass

    def ClientToScreen(self, pt):
        """"""
        pass

    def ClientToScreenXY(self, x, y):
        """"""
        pass

    def Close(self, force=False):
        """"""
        pass

    def ConvertDialogPointToPixels(self, pt):
        """"""
        pass

    def ConvertDialogSizeToPixels(self, sz):
        """"""
        pass

    def ConvertPixelPointToDialog(self, pt):
        """"""
        pass

    def ConvertPixelSizeToDialog(self, sz):
        """"""
        pass

    def Create(self, parent, id, pos=wx.DefaultPosition,
               size=wx.DefaultSize, style=0, name=wx.PyPanelNameStr):
        """"""
        pass

    def DLG_PNT(self, win, point_or_x, y=None):
        """"""
        pass

    def DLG_SZE(self, win, size_width, height=None):
        """"""
        pass

    def Destroy(self):
        """"""
        pass

    def DestroyChildren(self):
        """"""
        pass

    def DragAcceptFiles(self, accept):
        """Windows only."""
        pass

    def Enable(self, enable):
        """"""
        pass

    def FindWindowById(self, id):
        """"""
        pass

    def FindWindowByName(self, name):
        """"""
        pass

    def Fit(self):
        """"""
        pass

    def FitInside(self):
        """"""
        pass

    def Freeze(self):
        """"""
        pass

    def GetAcceleratorTable(self):
        """"""
        pass

    def GetAdjustedBestSize(self):
        """"""
        pass

    def GetAutoLayout(self):
        """"""
        pass

    def GetBackgroundColour(self):
        """"""
        pass

    def GetBestSize(self):
        """"""
        pass

    def GetBestVirtualSize(self):
        """"""
        pass

    def GetBorder(self):
        """"""
        pass

    def GetCaret(self):
        """"""
        pass

    def GetCharHeight(self):
        """"""
        pass

    def GetCharWidth(self):
        """"""
        pass

    def GetChildren(self):
        """"""
        pass

    def GetClientAreaOrigin(self):
        """"""
        pass

    def GetClientRect(self):
        """"""
        pass

    def GetClientSize(self):
        """"""
        pass

    def GetClientSizeTuple(self):
        """"""
        pass

    def GetConstraints(self):
        """"""
        pass

    def GetContainingSizer(self):
        """"""
        pass

    def GetCursor(self):
        """"""
        pass

    def GetDefaultItem(self):
        """"""
        pass

    def GetDropTarget(self):
        """"""
        pass

    def GetEventHandler(self):
        """"""
        pass

    def GetFont(self):
        """"""
        pass

    def GetForegroundColour(self):
        """"""
        pass

    def GetFullTextExtent(self):
        """"""
        pass

    def GetGrandParent(self):
        """"""
        pass

    def GetHandle(self):
        """"""
        pass

    def GetHelpText(self):
        """"""
        pass

    def GetId(self):
        """"""
        pass

    def GetLabel(self):
        """"""
        pass

    def GetMaxSize(self):
        """"""
        pass

    def GetName(self):
        """"""
        pass

    def GetParent(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def GetPositionTuple(self):
        """"""
        pass

    def GetRect(self):
        """"""
        pass

    def GetScrollPos(self, orientation):
        """"""
        pass

    def GetScrollRange(self, orientation):
        """"""
        pass

    def GetScrollThumb(self, orientation):
        """"""
        pass

    def GetSize(self):
        """"""
        pass

    def GetSizeTuple(self):
        """"""
        pass

    def GetSizer(self):
        """"""
        pass

    def GetTextExtent(self, string):
        """"""
        pass

    def GetTitle(self):
        """"""
        pass

    def GetToolTip(self):
        """"""
        pass

    def GetUpdateRegion(self):
        """"""
        pass

    def GetValidator(self):
        """"""
        pass

    def GetVirtualSize(self):
        """"""
        pass

    def GetVirtualSizeTuple(self):
        """"""
        pass

    def GetWindowStyleFlag(self):
        """"""
        pass

    def HasCapture(self):
        """"""
        pass

    def HasScrollbar(self, orient):
        """"""
        pass

    def Hide(self):
        """"""
        pass

    def HitTest(self, pt):
        """"""
        pass

    def InitDialog(self):
        """"""
        pass

    def IsBeingDeleted(self):
        """"""
        pass

    def IsEnabled(self):
        """"""
        pass

    def IsExposed(self, x, y, w=0, h=0):
        """"""
        pass

    def IsExposedPoint(self, pt):
        """"""
        pass

    def IsExposedRect(self, rect):
        """"""
        pass

    def IsRetained(self):
        """"""
        pass

    def IsShown(self):
        """"""
        pass

    def IsTopLevel(self):
        """"""
        pass

    def Layout(self):
        """"""
        pass

    def LineDown(self):
        """"""
        pass

    def LineUp(self):
        """"""
        pass

    def LoadFromResource(self, parent, resourceName, resourceTable=wx.NULL):
        """Only if USE_WX_RESOURCES."""
        pass

    def Lower(self):
        """"""
        pass

    def MakeModal(self, flag=True):
        """"""
        pass

    def Move(self, point, flags=wx.SIZE_USE_EXISTING):
        """"""
        pass

    def MoveXY(self, x, y, flags=wx.SIZE_USE_EXISTING):
        """"""
        pass

    def OnPaint(self, event):
        """Windows only."""
        pass

    def PageDown(self):
        """"""
        pass

    def PageUp(self):
        """"""
        pass

    def PopEventHandler(self, deleteHandler=False):
        """"""
        pass

    def PopupMenu(self, menu, pos):
        """"""
        pass

    def PopupMenuXY(self, menu, x, y):
        """"""
        pass

    def PushEventHandler(self, handler):
        """"""
        pass

    def Raise(self):
        """"""
        pass

    def Refresh(self, eraseBackground=True, rect=wx.NULL):
        """"""
        pass

    def RefreshRect(self, rect):
        """"""
        pass

    def ReleaseMouse(self):
        """"""
        pass

    def RemoveChild(self, child):
        """"""
        pass

    def RemoveEventHandler(self, handler):
        """"""
        pass

    def Reparent(self, newParent):
        """"""
        pass

    def ScreenToClient(self, pt):
        """"""
        pass

    def ScreenToClientXY(self, x, y):
        """"""
        pass

    def ScrollLines(self, lines):
        """"""
        pass

    def ScrollPages(self, pages):
        """"""
        pass

    def ScrollWindow(self, dx, dy, rect=wx.NULL):
        """"""
        pass

    def SetAcceleratorTable(self, accel):
        """"""
        pass

    def SetAutoLayout(self, autoLayout):
        """"""
        pass

    def SetBackgroundColour(self, colour):
        """"""
        pass

    def SetCaret(self, caret):
        """"""
        pass

    def SetClientSize(self, size):
        """"""
        pass

    def SetClientSizeWH(self, width, height):
        """"""
        pass

    def SetConstraints(self, constraints):
        """"""
        pass

    def SetContainingSizer(self, sizer):
        """"""
        pass

    def SetCursor(self, cursor):
        """"""
        pass

    def SetDefaultItem(self, btn):
        """"""
        pass

    def SetDimensions(self):
        """"""
        pass

    def SetDropTarget(self, target):
        """"""
        pass

    def SetEventHandler(self, handler):
        """"""
        pass

    def SetExtraStyle(self, exStyle):
        """"""
        pass

    def SetFocus(self):
        """"""
        pass

    def SetFocusFromKbd(self):
        """"""
        pass

    def SetFont(self, font):
        """"""
        pass

    def SetForegroundColour(self, colour):
        """"""
        pass

    def SetHelpText(self, helpText):
        """"""
        pass

    def SetHelpTextForId(self, text):
        """"""
        pass

    def SetId(self, id):
        """"""
        pass

    def SetLabel(self, label):
        """"""
        pass

    def SetName(self, name):
        """"""
        pass

    def SetPosition(self, pos, flags=wx.SIZE_USE_EXISTING):
        """"""
        pass

    def SetRect(self, rect, sizeFlags=wx.SIZE_AUTO):
        """"""
        pass

    def SetScrollPos(self, orientation, pos, refresh=True):
        """"""
        pass

    def SetScrollbar(self, orientation, pos, thumbSize, range, refresh=True):
        """"""
        pass

    def SetSize(self, x, y, width, height, sizeFlags=wx.SIZE_AUTO):
        """"""
        pass

    def SetSizeHints(self, minW, minH, maxW=-1, maxH=-1, incW=-1, incH=-1):
        """"""
        pass

    def SetSizer(self, sizer, deleteOld=True):
        """"""
        pass

    def SetSizerAndFit(self, sizer, deleteOld=True):
        """"""
        pass

    def SetTitle(self, title):
        """"""
        pass

    def SetTmpDefaultItem(self, win):
        """"""
        pass

    def SetToolTip(self, tooltip):
        """"""
        pass

    def SetToolTipString(self, tip):
        """"""
        pass

    def SetValidator(self, validator):
        """"""
        pass

    def SetVirtualSize(self, size):
        """"""
        pass

    def SetVirtualSizeHints(self, minW, minH, maxW=-1, maxH=-1):
        """"""
        pass

    def SetVirtualSizeWH(self, x, y):
        """"""
        pass

    def SetWindowStyle(self, style):
        """"""
        pass

    def SetWindowStyleFlag(self, style):
        """"""
        pass

    def Show(self, show=True):
        """"""
        pass

    def Thaw(self):
        """"""
        pass

    def TransferDataFromWindow(self):
        """"""
        pass

    def TransferDataToWindow(self):
        """"""
        pass

    def UnsetConstraints(self, constraints):
        """"""
        pass

    def Update(self):
        """"""
        pass

    def UpdateWindowUI(self):
        """"""
        pass

    def Validate(self):
        """"""
        pass

    def WarpPointer(self, x, y):
        """"""
        pass


class PyWindow(Window):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_AcceptsFocus(self):
        """"""
        pass

    def base_AcceptsFocusFromKeyboard(self):
        """"""
        pass

    def base_AddChild(self):
        """"""
        pass

    def base_DoGetBestSize(self):
        """"""
        pass

    def base_DoGetClientSize(self):
        """"""
        pass

    def base_DoGetPosition(self):
        """"""
        pass

    def base_DoGetSize(self):
        """"""
        pass

    def base_DoGetVirtualSize(self):
        """"""
        pass

    def base_DoMoveWindow(self):
        """"""
        pass

    def base_DoSetClientSize(self):
        """"""
        pass

    def base_DoSetSize(self):
        """"""
        pass

    def base_DoSetVirtualSize(self):
        """"""
        pass

    def base_GetMaxSize(self):
        """"""
        pass

    def base_InitDialog(self):
        """"""
        pass

    def base_RemoveChild(self):
        """"""
        pass

    def base_TransferDataFromWindow(self):
        """"""
        pass

    def base_TransferDataToWindow(self):
        """"""
        pass

    def base_Validate(self):
        """"""
        pass


class TopLevelWindow(Window):
    """"""

    def Create(self):
        """"""
        pass

    def GetIcon(self):
        """"""
        pass

    def GetTitle(self):
        """"""
        pass

    def Iconize(self):
        """"""
        pass

    def IsFullScreen(self):
        """"""
        pass

    def IsIconized(self):
        """"""
        pass

    def IsMaximized(self):
        """"""
        pass

    def Maximize(self):
        """"""
        pass

    def Restore(self):
        """"""
        pass

    def SetIcon(self):
        """"""
        pass

    def SetIcons(self):
        """"""
        pass

    def SetTitle(self):
        """"""
        pass

    def ShowFullScreen(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass





# This file was created automatically by SWIG.
import oglshapesc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *

from oglbasic import *
import wx
class wxPseudoMetaFilePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=oglshapesc.delete_wxPseudoMetaFile):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Draw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_Draw,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_Clear,(self,) + _args, _kwargs)
        return val
    def Copy(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_Copy,(self,) + _args, _kwargs)
        return val
    def Scale(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_Scale,(self,) + _args, _kwargs)
        return val
    def ScaleTo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_ScaleTo,(self,) + _args, _kwargs)
        return val
    def Translate(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_Translate,(self,) + _args, _kwargs)
        return val
    def Rotate(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_Rotate,(self,) + _args, _kwargs)
        return val
    def LoadFromMetaFile(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_LoadFromMetaFile,(self,) + _args, _kwargs)
        return val
    def GetBounds(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_GetBounds,(self,) + _args, _kwargs)
        return val
    def CalculateSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_CalculateSize,(self,) + _args, _kwargs)
        return val
    def SetRotateable(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetRotateable,(self,) + _args, _kwargs)
        return val
    def GetRotateable(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_GetRotateable,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetSize,(self,) + _args, _kwargs)
        return val
    def SetFillBrush(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetFillBrush,(self,) + _args, _kwargs)
        return val
    def GetFillBrush(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_GetFillBrush,(self,) + _args, _kwargs)
        if val: val = wxBrushPtr(val) 
        return val
    def SetOutlinePen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetOutlinePen,(self,) + _args, _kwargs)
        return val
    def GetOutlinePen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_GetOutlinePen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) 
        return val
    def SetOutlineOp(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetOutlineOp,(self,) + _args, _kwargs)
        return val
    def GetOutlineOp(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_GetOutlineOp,(self,) + _args, _kwargs)
        return val
    def IsValid(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_IsValid,(self,) + _args, _kwargs)
        return val
    def DrawLine(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawLine,(self,) + _args, _kwargs)
        return val
    def DrawRectangle(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawRectangle,(self,) + _args, _kwargs)
        return val
    def DrawRoundedRectangle(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawRoundedRectangle,(self,) + _args, _kwargs)
        return val
    def DrawArc(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawArc,(self,) + _args, _kwargs)
        return val
    def DrawEllipticArc(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawEllipticArc,(self,) + _args, _kwargs)
        return val
    def DrawEllipse(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawEllipse,(self,) + _args, _kwargs)
        return val
    def DrawPoint(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawPoint,(self,) + _args, _kwargs)
        return val
    def DrawText(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawText,(self,) + _args, _kwargs)
        return val
    def DrawLines(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawLines,(self,) + _args, _kwargs)
        return val
    def DrawPolygon(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawPolygon,(self,) + _args, _kwargs)
        return val
    def DrawSpline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DrawSpline,(self,) + _args, _kwargs)
        return val
    def SetClippingRect(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetClippingRect,(self,) + _args, _kwargs)
        return val
    def DestroyClippingRect(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_DestroyClippingRect,(self,) + _args, _kwargs)
        return val
    def SetPen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetPen,(self,) + _args, _kwargs)
        return val
    def SetBrush(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetBrush,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetFont,(self,) + _args, _kwargs)
        return val
    def SetTextColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetTextColour,(self,) + _args, _kwargs)
        return val
    def SetBackgroundColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetBackgroundMode(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPseudoMetaFile_SetBackgroundMode,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPseudoMetaFile instance at %s>" % (self.this,)
class wxPseudoMetaFile(wxPseudoMetaFilePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPseudoMetaFile,_args,_kwargs)
        self.thisown = 1




class wxPyRectangleShapePtr(wxPyShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def SetCornerRadius(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_SetCornerRadius,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyRectangleShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyRectangleShape instance at %s>" % (self.this,)
class wxPyRectangleShape(wxPyRectangleShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyRectangleShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyRectangleShape)
        self._setOORInfo(self)




class wxPyControlPointPtr(wxPyRectangleShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def SetCornerRadius(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_SetCornerRadius,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyControlPoint_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyControlPoint instance at %s>" % (self.this,)
class wxPyControlPoint(wxPyControlPointPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyControlPoint,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyControlPoint)
        self._setOORInfo(self)




class wxPyBitmapShapePtr(wxPyRectangleShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) 
        return val
    def GetFilename(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_GetFilename,(self,) + _args, _kwargs)
        return val
    def SetBitmap(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_SetBitmap,(self,) + _args, _kwargs)
        return val
    def SetFilename(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_SetFilename,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyBitmapShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyBitmapShape instance at %s>" % (self.this,)
class wxPyBitmapShape(wxPyBitmapShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyBitmapShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyBitmapShape)
        self._setOORInfo(self)




class wxPyDrawnShapePtr(wxPyRectangleShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def CalculateSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_CalculateSize,(self,) + _args, _kwargs)
        return val
    def DestroyClippingRect(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DestroyClippingRect,(self,) + _args, _kwargs)
        return val
    def DrawArc(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawArc,(self,) + _args, _kwargs)
        return val
    def DrawAtAngle(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawAtAngle,(self,) + _args, _kwargs)
        return val
    def DrawEllipticArc(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawEllipticArc,(self,) + _args, _kwargs)
        return val
    def DrawLine(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawLine,(self,) + _args, _kwargs)
        return val
    def DrawLines(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawLines,(self,) + _args, _kwargs)
        return val
    def DrawPoint(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawPoint,(self,) + _args, _kwargs)
        return val
    def DrawPolygon(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawPolygon,(self,) + _args, _kwargs)
        return val
    def DrawRectangle(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawRectangle,(self,) + _args, _kwargs)
        return val
    def DrawRoundedRectangle(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawRoundedRectangle,(self,) + _args, _kwargs)
        return val
    def DrawSpline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawSpline,(self,) + _args, _kwargs)
        return val
    def DrawText(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_DrawText,(self,) + _args, _kwargs)
        return val
    def GetAngle(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_GetAngle,(self,) + _args, _kwargs)
        return val
    def GetMetaFile(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_GetMetaFile,(self,) + _args, _kwargs)
        return val
    def GetRotation(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_GetRotation,(self,) + _args, _kwargs)
        return val
    def LoadFromMetaFile(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_LoadFromMetaFile,(self,) + _args, _kwargs)
        return val
    def Rotate(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_Rotate,(self,) + _args, _kwargs)
        return val
    def SetClippingRect(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetClippingRect,(self,) + _args, _kwargs)
        return val
    def SetDrawnBackgroundColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetDrawnBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetDrawnBackgroundMode(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetDrawnBackgroundMode,(self,) + _args, _kwargs)
        return val
    def SetDrawnBrush(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetDrawnBrush,(self,) + _args, _kwargs)
        return val
    def SetDrawnFont(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetDrawnFont,(self,) + _args, _kwargs)
        return val
    def SetDrawnPen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetDrawnPen,(self,) + _args, _kwargs)
        return val
    def SetDrawnTextColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetDrawnTextColour,(self,) + _args, _kwargs)
        return val
    def Scale(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_Scale,(self,) + _args, _kwargs)
        return val
    def SetSaveToFile(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_SetSaveToFile,(self,) + _args, _kwargs)
        return val
    def Translate(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_Translate,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDrawnShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyDrawnShape instance at %s>" % (self.this,)
class wxPyDrawnShape(wxPyDrawnShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyDrawnShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyDrawnShape)
        self._setOORInfo(self)




class wxOGLConstraintPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Evaluate(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxOGLConstraint_Evaluate,(self,) + _args, _kwargs)
        return val
    def SetSpacing(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxOGLConstraint_SetSpacing,(self,) + _args, _kwargs)
        return val
    def Equals(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxOGLConstraint_Equals,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxOGLConstraint instance at %s>" % (self.this,)
class wxOGLConstraint(wxOGLConstraintPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxOGLConstraint,_args,_kwargs)
        self.thisown = 1




class wxPyCompositeShapePtr(wxPyRectangleShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def AddChild(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_AddChild,(self,) + _args, _kwargs)
        return val
    def AddConstraint(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_AddConstraint,(self,) + _args, _kwargs)
        return val
    def AddConstrainedShapes(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_AddConstrainedShapes,(self,) + _args, _kwargs)
        return val
    def AddSimpleConstraint(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_AddSimpleConstraint,(self,) + _args, _kwargs)
        return val
    def CalculateSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_CalculateSize,(self,) + _args, _kwargs)
        return val
    def ContainsDivision(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_ContainsDivision,(self,) + _args, _kwargs)
        return val
    def DeleteConstraint(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_DeleteConstraint,(self,) + _args, _kwargs)
        return val
    def DeleteConstraintsInvolvingChild(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_DeleteConstraintsInvolvingChild,(self,) + _args, _kwargs)
        return val
    def FindContainerImage(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_FindContainerImage,(self,) + _args, _kwargs)
        return val
    def GetConstraints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_GetConstraints,(self,) + _args, _kwargs)
        return val
    def GetDivisions(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_GetDivisions,(self,) + _args, _kwargs)
        return val
    def MakeContainer(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_MakeContainer,(self,) + _args, _kwargs)
        return val
    def Recompute(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_Recompute,(self,) + _args, _kwargs)
        return val
    def RemoveChild(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_RemoveChild,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyCompositeShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyCompositeShape instance at %s>" % (self.this,)
class wxPyCompositeShape(wxPyCompositeShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyCompositeShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyCompositeShape)
        self._setOORInfo(self)




class wxPyDividedShapePtr(wxPyRectangleShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def EditRegions(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_EditRegions,(self,) + _args, _kwargs)
        return val
    def SetRegionSizes(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_SetRegionSizes,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDividedShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyDividedShape instance at %s>" % (self.this,)
class wxPyDividedShape(wxPyDividedShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyDividedShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyDividedShape)
        self._setOORInfo(self)




class wxPyDivisionShapePtr(wxPyCompositeShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def AdjustBottom(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_AdjustBottom,(self,) + _args, _kwargs)
        return val
    def AdjustLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_AdjustLeft,(self,) + _args, _kwargs)
        return val
    def AdjustRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_AdjustRight,(self,) + _args, _kwargs)
        return val
    def AdjustTop(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_AdjustTop,(self,) + _args, _kwargs)
        return val
    def Divide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_Divide,(self,) + _args, _kwargs)
        return val
    def EditEdge(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_EditEdge,(self,) + _args, _kwargs)
        return val
    def GetBottomSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetBottomSide,(self,) + _args, _kwargs)
        return val
    def GetHandleSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetHandleSide,(self,) + _args, _kwargs)
        return val
    def GetLeftSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetLeftSide,(self,) + _args, _kwargs)
        return val
    def GetLeftSideColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetLeftSideColour,(self,) + _args, _kwargs)
        return val
    def GetLeftSidePen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetLeftSidePen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) 
        return val
    def GetRightSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetRightSide,(self,) + _args, _kwargs)
        return val
    def GetTopSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetTopSide,(self,) + _args, _kwargs)
        return val
    def GetTopSidePen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_GetTopSidePen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) 
        return val
    def ResizeAdjoining(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_ResizeAdjoining,(self,) + _args, _kwargs)
        return val
    def PopupMenu(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_PopupMenu,(self,) + _args, _kwargs)
        return val
    def SetBottomSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetBottomSide,(self,) + _args, _kwargs)
        return val
    def SetHandleSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetHandleSide,(self,) + _args, _kwargs)
        return val
    def SetLeftSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetLeftSide,(self,) + _args, _kwargs)
        return val
    def SetLeftSideColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetLeftSideColour,(self,) + _args, _kwargs)
        return val
    def SetLeftSidePen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetLeftSidePen,(self,) + _args, _kwargs)
        return val
    def SetRightSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetRightSide,(self,) + _args, _kwargs)
        return val
    def SetTopSide(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetTopSide,(self,) + _args, _kwargs)
        return val
    def SetTopSideColour(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetTopSideColour,(self,) + _args, _kwargs)
        return val
    def SetTopSidePen(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_SetTopSidePen,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapesc.wxPyDivisionShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyDivisionShape instance at %s>" % (self.this,)
class wxPyDivisionShape(wxPyDivisionShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapesc.new_wxPyDivisionShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyDivisionShape)
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------




"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: MimeTypes.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


class FileType:
    """"""

    def GetAllCommands(self):
        """"""
        pass

    def GetDescription(self):
        """"""
        pass

    def GetExtensions(self):
        """"""
        pass

    def GetIcon(self):
        """"""
        pass

    def GetIconInfo(self):
        """"""
        pass

    def GetMimeType(self):
        """"""
        pass

    def GetMimeTypes(self):
        """"""
        pass

    def GetOpenCommand(self):
        """"""
        pass

    def GetPrintCommand(self):
        """"""
        pass

    def SetCommand(self):
        """"""
        pass

    def SetDefaultIcon(self):
        """"""
        pass

    def Unassociate(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FileTypeInfo:
    """"""

    def GetDescription(self):
        """"""
        pass

    def GetExtensions(self):
        """"""
        pass

    def GetExtensionsCount(self):
        """"""
        pass

    def GetIconFile(self):
        """"""
        pass

    def GetIconIndex(self):
        """"""
        pass

    def GetMimeType(self):
        """"""
        pass

    def GetOpenCommand(self):
        """"""
        pass

    def GetPrintCommand(self):
        """"""
        pass

    def GetShortDesc(self):
        """"""
        pass

    def IsValid(self):
        """"""
        pass

    def SetIcon(self):
        """"""
        pass

    def SetShortDesc(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class MimeTypesManager:
    """"""

    def AddFallback(self):
        """"""
        pass

    def Associate(self):
        """"""
        pass

    def ClearData(self):
        """"""
        pass

    def EnumAllFileTypes(self):
        """"""
        pass

    def GetFileTypeFromExtension(self):
        """"""
        pass

    def GetFileTypeFromMimeType(self):
        """"""
        pass

    def Initialize(self):
        """"""
        pass

    def ReadMailcap(self):
        """"""
        pass

    def ReadMimeTypes(self):
        """"""
        pass

    def Unassociate(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass





"""Provides a variety of introspective-type support functions for
things like call tips and command auto completion."""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: introspect.py,v 1.14.2.3 2003/03/05 20:24:17 RD Exp $"
__revision__ = "$Revision: 1.14.2.3 $"[11:-2]

from __future__ import nested_scopes

import cStringIO
import inspect
import tokenize
import types

try:
    True
except NameError:
    True = 1==1
    False = 1==0

def getAutoCompleteList(command='', locals=None, includeMagic=1, 
                        includeSingle=1, includeDouble=1):
    """Return list of auto-completion options for command.
    
    The list of options will be based on the locals namespace."""
    attributes = []
    # Get the proper chunk of code from the command.
    root = getRoot(command, terminator='.')
    try:
        if locals is not None:
            object = eval(root, locals)
        else:
            object = eval(root)
    except:
        pass
    else:
        attributes = getAttributeNames(object, includeMagic, 
                                       includeSingle, includeDouble)
    return attributes
    
def getAttributeNames(object, includeMagic=1, includeSingle=1,
                      includeDouble=1):
    """Return list of unique attributes, including inherited, for object."""
    attributes = []
    dict = {}
    if not hasattrAlwaysReturnsTrue(object):
        # Add some attributes that don't always get picked up.  If
        # they don't apply, they'll get filtered out at the end.
        attributes += ['__bases__', '__class__', '__dict__', '__name__', 
                       'func_closure', 'func_code', 'func_defaults', 
                       'func_dict', 'func_doc', 'func_globals', 'func_name']
    if includeMagic:
        try: attributes += object._getAttributeNames()
        except: pass
    # Get all attribute names.
    attrdict = getAllAttributeNames(object)
    for attrlist in attrdict.values():
        attributes += attrlist
    # Remove duplicates from the attribute list.
    for item in attributes:
        dict[item] = None
    attributes = dict.keys()
    attributes.sort(lambda x, y: cmp(x.upper(), y.upper()))
    if not includeSingle:
        attributes = filter(lambda item: item[0]!='_' \
                            or item[1]=='_', attributes)
    if not includeDouble:
        attributes = filter(lambda item: item[:2]!='__', attributes)
    # Make sure we haven't picked up any bogus attributes somehow.
    attributes = [attribute for attribute in attributes \
                  if hasattr(object, attribute)]
    return attributes

def hasattrAlwaysReturnsTrue(object):
    return hasattr(object, 'bogu5_123_aTTri8ute')

def getAllAttributeNames(object):
    """Return dict of all attributes, including inherited, for an object.
    
    Recursively walk through a class and all base classes.
    """
    attrdict = {}  # (object, technique, count): [list of attributes]
    # !!!
    # Do Not use hasattr() as a test anywhere in this function,
    # because it is unreliable with remote objects: xmlrpc, soap, etc.
    # They always return true for hasattr().
    # !!!
    try:
        # Yes, this can fail if object is an instance of a class with
        # __str__ (or __repr__) having a bug or raising an
        # exception. :-(
        key = str(object)
    except:
        key = 'anonymous'
    # Wake up sleepy objects - a hack for ZODB objects in "ghost" state.
    wakeupcall = dir(object)
    del wakeupcall
    # Get attributes available through the normal convention.
    attributes = dir(object)
    attrdict[(key, 'dir', len(attributes))] = attributes
    # Get attributes from the object's dictionary, if it has one.
    try:
        attributes = object.__dict__.keys()
        attributes.sort()
    except:  # Must catch all because object might have __getattr__.
        pass
    else:
        attrdict[(key, '__dict__', len(attributes))] = attributes
    # For a class instance, get the attributes for the class.
    try:
        klass = object.__class__
    except:  # Must catch all because object might have __getattr__.
        pass
    else:
        if klass is object:
            # Break a circular reference. This happens with extension
            # classes.
            pass
        else:
            attrdict.update(getAllAttributeNames(klass))
    # Also get attributes from any and all parent classes.
    try:
        bases = object.__bases__
    except:  # Must catch all because object might have __getattr__.
        pass
    else:
        if isinstance(bases, types.TupleType):
            for base in bases:
                if type(base) is types.TypeType:
                    # Break a circular reference. Happens in Python 2.2.
                    pass
                else:
                    attrdict.update(getAllAttributeNames(base))
    return attrdict

def getCallTip(command='', locals=None):
    """For a command, return a tuple of object name, argspec, tip text.
    
    The call tip information will be based on the locals namespace."""
    calltip = ('', '', '')  # object name, argspec, tip text.
    # Get the proper chunk of code from the command.
    root = getRoot(command, terminator='(')
    try:
        if locals is not None:
            object = eval(root, locals)
        else:
            object = eval(root)
    except:
        return calltip
    name = ''
    object, dropSelf = getBaseObject(object)
    try:
        name = object.__name__
    except AttributeError:
        pass
    tip1 = ''
    argspec = ''
    if inspect.isbuiltin(object):
        # Builtin functions don't have an argspec that we can get.
        pass
    elif inspect.isfunction(object):
        # tip1 is a string like: "getCallTip(command='', locals=None)"
        argspec = apply(inspect.formatargspec, inspect.getargspec(object))
        if dropSelf:
            # The first parameter to a method is a reference to an
            # instance, usually coded as "self", and is usually passed
            # automatically by Python; therefore we want to drop it.
            temp = argspec.split(',')
            if len(temp) == 1:  # No other arguments.
                argspec = '()'
            else:  # Drop the first argument.
                argspec = '(' + ','.join(temp[1:]).lstrip()
        tip1 = name + argspec
    doc = ''
    if callable(object):
        doc = inspect.getdoc(object)
    if doc:
        # tip2 is the first separated line of the docstring, like:
        # "Return call tip text for a command."
        # tip3 is the rest of the docstring, like:
        # "The call tip information will be based on ... <snip>
        firstline = doc.split('\n')[0].lstrip()
        if tip1 == firstline:
            tip1 = ''
        else:
            tip1 += '\n\n'
        docpieces = doc.split('\n\n')
        tip2 = docpieces[0]
        tip3 = '\n\n'.join(docpieces[1:])
        tip = '%s%s\n\n%s' % (tip1, tip2, tip3)
    else:
        tip = tip1
    calltip = (name, argspec[1:-1], tip.strip())
    return calltip

def getRoot(command, terminator=None):
    """Return the rightmost root portion of an arbitrary Python command.
    
    Return only the root portion that can be eval()'d without side
    effects.  The command would normally terminate with a '(' or
    '.'. The terminator and anything after the terminator will be
    dropped."""
    command = rtrimTerminus(command, terminator)
    tokens = getTokens(command)
    if not tokens:
        return ''
    if tokens[-1][0] is tokenize.ENDMARKER:
        # Remove the end marker.
        del tokens[-1]
    if terminator == '.' and \
           (tokens[-1][1] <> '.' or tokens[-1][0] is not tokenize.OP):
        # Trap decimals in numbers, versus the dot operator.
        return ''
    else:
        # Strip off the terminator.
        command = command[:-1]
    command = command.rstrip()
    tokens = getTokens(command)
    tokens.reverse()
    line = ''
    start = None
    prefix = ''
    laststring = '.'
    emptyTypes = ('[]', '()', '{}')
    for token in tokens:
        tokentype = token[0]
        tokenstring = token[1]
        line = token[4]
        if tokentype is tokenize.ENDMARKER:
            continue
        if tokentype in (tokenize.NAME, tokenize.STRING, tokenize.NUMBER) \
        and laststring != '.':
            # We've reached something that's not part of the root.
            if prefix and line[token[3][1]] != ' ':
                # If it doesn't have a space after it, remove the prefix.
                prefix = ''
            break
        if tokentype in (tokenize.NAME, tokenize.STRING, tokenize.NUMBER) \
        or (tokentype is tokenize.OP and tokenstring == '.'):
            if prefix:
                # The prefix isn't valid because it comes after a dot.
                prefix = ''
                break
            else:
                # start represents the last known good point in the line.
                start = token[2][1]
        elif len(tokenstring) == 1 and tokenstring in ('[({])}'):
            # Remember, we're working backwords.
            # So prefix += tokenstring would be wrong.
            if prefix in emptyTypes and tokenstring in ('[({'):
                # We've already got an empty type identified so now we
                # are in a nested situation and we can break out with
                # what we've got.
                break
            else:
                prefix = tokenstring + prefix
        else:
            # We've reached something that's not part of the root.
            break
        laststring = tokenstring
    if start is None:
        start = len(line)
    root = line[start:]
    if prefix in emptyTypes:
        # Empty types are safe to be eval()'d and introspected.
        root = prefix + root
    return root    

def getTokens(command):
    """Return list of token tuples for command."""
    command = str(command)  # In case the command is unicode, which fails.
    f = cStringIO.StringIO(command)
    # tokens is a list of token tuples, each looking like: 
    # (type, string, (srow, scol), (erow, ecol), line)
    tokens = []
    # Can't use list comprehension:
    #   tokens = [token for token in tokenize.generate_tokens(f.readline)]
    # because of need to append as much as possible before TokenError.
    try:
##        This code wasn't backward compatible with Python 2.1.3.
##
##        for token in tokenize.generate_tokens(f.readline):
##            tokens.append(token)

        # This works with Python 2.1.3 (with nested_scopes).
        def eater(*args):
            tokens.append(args)
        tokenize.tokenize_loop(f.readline, eater)
    except tokenize.TokenError:
        # This is due to a premature EOF, which we expect since we are
        # feeding in fragments of Python code.
        pass
    return tokens    

def rtrimTerminus(command, terminator=None):
    """Return command minus anything that fillows the final terminator."""
    if terminator:
        pieces = command.split(terminator)
        if len(pieces) > 1:
            command = terminator.join(pieces[:-1]) + terminator
    return command

def getBaseObject(object):
    """Return base object and dropSelf indicator for an object."""
    if inspect.isbuiltin(object):
        # Builtin functions don't have an argspec that we can get.
        dropSelf = 0
    elif inspect.ismethod(object):
        # Get the function from the object otherwise
        # inspect.getargspec() complains that the object isn't a
        # Python function.
        try:
            if object.im_self is None:
                # This is an unbound method so we do not drop self
                # from the argspec, since an instance must be passed
                # as the first arg.
                dropSelf = 0
            else:
                dropSelf = 1
            object = object.im_func
        except AttributeError:
            dropSelf = 0
    elif inspect.isclass(object):
        # Get the __init__ method function for the class.
        constructor = getConstructor(object)
        if constructor is not None:
            object = constructor
            dropSelf = 1
        else:
            dropSelf = 0
    elif callable(object):
        # Get the __call__ method instead.
        try:
            object = object.__call__.im_func
            dropSelf = 1
        except AttributeError:
            dropSelf = 0
    else:
        dropSelf = 0
    return object, dropSelf

def getConstructor(object):
    """Return constructor for class object, or None if there isn't one."""
    try:
        return object.__init__.im_func
    except AttributeError:
        for base in object.__bases__:
            constructor = getConstructor(base)
            if constructor is not None:
                return constructor
    return None



# Name:         params.py
# Purpose:      Classes for parameter introduction
# Author:       Roman Rolinsky <rolinsky@mema.ucl.ac.be>
# Created:      22.08.2001
# RCS-ID:       $Id: params.py,v 1.2.2.9 2003/03/20 20:01:51 ROL Exp $

import string
import os.path
from globals import *
from types import *
from wxPython.xrc import *

genericStyles = ['wxSIMPLE_BORDER', 'wxDOUBLE_BORDER',
                 'wxSUNKEN_BORDER', 'wxRAISED_BORDER',
                 'wxSTATIC_BORDER', 'wxNO_BORDER',
                 'wxTRANSPARENT_WINDOW', 'wxWANTS_CHARS',
                 'wxNO_FULL_REPAINT_ON_RESIZE']

buttonSize = (30,-1)    # in dialog units, transformed to pixels in panel ctor

# Class that can properly disable children
class PPanel(wxPanel):
    def __init__(self, parent, name):
        wxPanel.__init__(self, parent, -1, name=name)
        self.modified = self.freeze = False
    def Enable(self, value):
        # Something strange is going on with enable so we make sure...
        for w in self.GetChildren():
            w.Enable(value)
        wxPanel.Enable(self, value)
    def SetModified(self):
        self.modified = True
        g.panel.SetModified(True)
    # Common method to set modified state
    def OnChange(self, evt):
        if self.freeze: return
        self.SetModified()
        evt.Skip()

class ParamBinaryOr(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        self.ID_BUTTON_CHOICES = wxNewId()
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer = wxBoxSizer()
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=wxSize(200,-1))
        sizer.Add(self.text, 0, wxRIGHT | wxALIGN_CENTER_VERTICAL, 5)
        self.button = wxButton(self, self.ID_BUTTON_CHOICES, 'Edit...', size=buttonSize)
        sizer.Add(self.button, 0, wxALIGN_CENTER_VERTICAL)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        EVT_BUTTON(self, self.ID_BUTTON_CHOICES, self.OnButtonChoices)
        EVT_TEXT(self, self.ID_TEXT_CTRL, self.OnChange)
    def GetValue(self):
        return self.text.GetValue()
    def SetValue(self, value):
        self.freeze = True
        self.text.SetValue(value)
        self.freeze = False
    def OnButtonChoices(self, evt):
        dlg = wxDialog(self, -1, 'Choices')
        topSizer = wxBoxSizer(wxVERTICAL)
        listBox = wxCheckListBox(dlg, -1, choices=self.values, size=(250,200))
        value = map(string.strip, self.text.GetValue().split('|'))
        if value == ['']: value = []
        ignored = []
        for i in value:
            try:
                listBox.Check(self.values.index(i))
            except ValueError:
                # Try to find equal
                if self.equal.has_key(i):
                    listBox.Check(self.values.index(self.equal[i]))
                else:
                    print 'WARNING: unknown flag: %s: ignored.' % i
                    ignored.append(i)
        topSizer.Add(listBox, 1, wxEXPAND)
        sizer = wxBoxSizer()
        buttonOk = wxButton(dlg, wxID_OK, 'OK')
        buttonOk.SetDefault()
        sizer.Add(buttonOk, 0, wxRIGHT, 10)
        sizer.Add(0, 0, 1)
        sizer.Add(wxButton(dlg, wxID_CANCEL, 'Cancel'))
        topSizer.Add(sizer, 0, wxALL | wxEXPAND, 10)
        dlg.SetAutoLayout(True)
        dlg.SetSizer(topSizer)
        topSizer.Fit(dlg)
        dlg.Center()
        if dlg.ShowModal() == wxID_OK:
            value = []
            for i in range(listBox.Number()):
                if listBox.IsChecked(i):
                    value.append(self.values[i])
            # Add ignored flags
            value.extend(ignored)
            if value:
                self.SetValue(reduce(lambda a,b: a+'|'+b, value))
            else:
                self.SetValue('')
            self.SetModified()
        dlg.Destroy()

class ParamFlag(ParamBinaryOr):
    values = ['wxTOP', 'wxBOTTOM', 'wxLEFT', 'wxRIGHT', 'wxALL',
              'wxEXPAND', 'wxGROW', 'wxSHAPED', 'wxALIGN_CENTRE', 'wxALIGN_RIGHT',
              'wxALIGN_BOTTOM', 'wxALIGN_CENTRE_VERTICAL',
              'wxALIGN_CENTRE_HORIZONTAL']
    equal = {'wxALIGN_CENTER': 'wxALIGN_CENTRE',
             'wxALIGN_CENTER_VERTICAL': 'wxALIGN_CENTRE_VERTICAL',
             'wxALIGN_CENTER_HORIZONTAL': 'wxALIGN_CENTRE_HORIZONTAL'}
    def __init__(self, parent, name):
        ParamBinaryOr.__init__(self, parent, name)

class ParamStyle(ParamBinaryOr):
    equal = {'wxALIGN_CENTER': 'wxALIGN_CENTRE'}
    def __init__(self, parent, name):
        self.values = g.currentXXX.winStyles + genericStyles
        ParamBinaryOr.__init__(self, parent, name)

class ParamNonGenericStyle(ParamBinaryOr):
    def __init__(self, parent, name):
        self.values = g.currentXXX.winStyles
        ParamBinaryOr.__init__(self, parent, name)

class ParamExStyle(ParamBinaryOr):
    def __init__(self, parent, name):
        if g.currentXXX:
            self.values = g.currentXXX.exStyles # constant at the moment
        else:
            self.values = []
        ParamBinaryOr.__init__(self, parent, name)

class ParamColour(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        self.ID_BUTTON = wxNewId()
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer = wxBoxSizer()
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=(65,-1))
        sizer.Add(self.text, 0, wxRIGHT, 5)
        self.button = wxPanel(self, self.ID_BUTTON, wxDefaultPosition, wxSize(20, 20))
        sizer.Add(self.button, 0, wxGROW)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        self.textModified = False
        EVT_PAINT(self.button, self.OnPaintButton)
        EVT_TEXT(self, self.ID_TEXT_CTRL, self.OnChange)
        EVT_LEFT_DOWN(self.button, self.OnLeftDown)
    def GetValue(self):
        return self.text.GetValue()
    def SetValue(self, value):
        self.freeze = True
        if not value: value = '#FFFFFF'
        self.text.SetValue(str(value))  # update text ctrl
        colour = wxColour(int(value[1:3], 16), int(value[3:5], 16), int(value[5:7], 16))
        self.button.SetBackgroundColour(colour)
        self.button.Refresh()
        self.freeze = False
    def OnPaintButton(self, evt):
        dc = wxPaintDC(self.button)
        dc.SetBrush(wxTRANSPARENT_BRUSH)
        if self.IsEnabled(): dc.SetPen(wxBLACK_PEN)
        else: dc.SetPen(wxGREY_PEN)
        size = self.button.GetSize()
        dc.DrawRectangle(0, 0, size.x, size.y)
    def OnLeftDown(self, evt):
        data = wxColourData()
        data.SetColour(self.GetValue())
        dlg = wxColourDialog(self, data)
        if dlg.ShowModal() == wxID_OK:
            self.SetValue('#%02X%02X%02X' % dlg.GetColourData().GetColour().Get())
            self.SetModified()
        dlg.Destroy()

################################################################################

# Mapping from wx constants ro XML strings
fontFamiliesWx2Xml = {wxDEFAULT: 'default', wxDECORATIVE: 'decorative',
                wxROMAN: 'roman', wxSCRIPT: 'script', wxSWISS: 'swiss',
                wxMODERN: 'modern'}
fontStylesWx2Xml = {wxNORMAL: 'normal', wxSLANT: 'slant', wxITALIC: 'italic'}
fontWeightsWx2Xml = {wxNORMAL: 'normal', wxLIGHT: 'light', wxBOLD: 'bold'}
def ReverseMap(m):
    rm = {}
    for k,v in m.items(): rm[v] = k
    return rm
fontFamiliesXml2wx = ReverseMap(fontFamiliesWx2Xml)
fontStylesXml2wx = ReverseMap(fontStylesWx2Xml)
fontWeightsXml2wx = ReverseMap(fontWeightsWx2Xml)

class ParamFont(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        self.ID_BUTTON_SELECT = wxNewId()
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer = wxBoxSizer()
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=wxSize(200,-1))
        sizer.Add(self.text, 0, wxRIGHT | wxALIGN_CENTER_VERTICAL, 5)
        self.button = wxButton(self, self.ID_BUTTON_SELECT, 'Select...', size=buttonSize)
        sizer.Add(self.button, 0, wxALIGN_CENTER_VERTICAL)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        self.textModified = False
        EVT_BUTTON(self, self.ID_BUTTON_SELECT, self.OnButtonSelect)
        EVT_TEXT(self, self.ID_TEXT_CTRL, self.OnChange)
    def OnChange(self, evt):
        PPanel.OnChange(self, evt)
        self.textModified = True
    def _defaultValue(self):
        return ['12', 'default', 'normal', 'normal', '0', '', '']
    def GetValue(self):
        if self.textModified:           # text has newer value
            try:
                return eval(self.text.GetValue())
            except SyntaxError:
                wxLogError('Syntax error in parameter value: ' + self.GetName())
                return self._defaultValue()
        return self.value
    def SetValue(self, value):
        self.freeze = True              # disable other handlers
        if not value: value = self._defaultValue()
        self.value = value
        self.text.SetValue(str(value))  # update text ctrl
        self.freeze = False
    def OnButtonSelect(self, evt):
        if self.textModified:           # text has newer value
            try:
                self.value = eval(self.text.GetValue())
            except SyntaxError:
                wxLogError('Syntax error in parameter value: ' + self.GetName())
                self.value = self._defaultValue()
        # Make initial font
        # Default values
        size = 12
        family = wxDEFAULT
        style = weight = wxNORMAL
        underlined = 0
        face = ''
        enc = wxFONTENCODING_DEFAULT
        # Fall back to default if exceptions
        error = False
        try:
            try: size = int(self.value[0])
            except ValueError: error = True
            try: family = fontFamiliesXml2wx[self.value[1]]
            except KeyError: error = True
            try: style = fontStylesXml2wx[self.value[2]]
            except KeyError: error = True
            try: weight = fontWeightsXml2wx[self.value[3]]
            except KeyError: error = True
            try: underlined = int(self.value[4])
            except ValueError: error = True
            face = self.value[5]
            mapper = wxFontMapper()
            if not self.value[6]: enc = mapper.CharsetToEncoding(self.value[6])
        except IndexError:
            error = True
        if error: wxLogError('Invalid font specification')
        if enc == wxFONTENCODING_DEFAULT: enc = wxFONTENCODING_SYSTEM
        font = wxFont(size, family, style, weight, underlined, face, enc)
        data = wxFontData()
        data.SetInitialFont(font)
        dlg = wxFontDialog(self, data)
        if dlg.ShowModal() == wxID_OK:
            font = dlg.GetFontData().GetChosenFont()
            value = [str(font.GetPointSize()),
                     fontFamiliesWx2Xml.get(font.GetFamily(), "default"),
                     fontStylesWx2Xml.get(font.GetStyle(), "normal"),
                     fontWeightsWx2Xml.get(font.GetWeight(), "normal"),
                     str(font.GetUnderlined()),
                     font.GetFaceName(),
                     wxFontMapper_GetEncodingName(font.GetEncoding())
                     ]
            # Add ignored flags
            self.SetValue(value)
            self.SetModified()
            self.textModified = False
        dlg.Destroy()

################################################################################

class ParamInt(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_SPIN_CTRL = wxNewId()
        sizer = wxBoxSizer()
        self.spin = wxSpinCtrl(self, self.ID_SPIN_CTRL, size=wxSize(50,-1))
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer.Add(self.spin)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        EVT_SPINCTRL(self, self.ID_SPIN_CTRL, self.OnChange)
    def GetValue(self):
        return str(self.spin.GetValue())
    def SetValue(self, value):
        self.freeze = True
        if not value: value = 0
        self.spin.SetValue(int(value))
        self.freeze = False

# Same as int but allows dialog units (XXXd)
class ParamUnit(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        self.ID_SPIN_BUTTON = wxNewId()
        sizer = wxBoxSizer()
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=wxSize(35,-1))
        self.spin = wxSpinButton(self, self.ID_SPIN_BUTTON, style = wxSP_VERTICAL)
        self.spin.SetRange(-10000, 10000)
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer.Add(self.text, 0, wxEXPAND | wxRIGHT, 2)
        sizer.Add(self.spin)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        EVT_SPIN_UP(self, self.ID_SPIN_BUTTON, self.OnSpinUp)
        EVT_SPIN_DOWN(self, self.ID_SPIN_BUTTON, self.OnSpinDown)
    def GetValue(self):
        return self.text.GetValue()
    def SetValue(self, value):
        self.freeze = True
        if not value: value = '0'
        self.text.SetValue(value)
        self.freeze = False
    def Change(self, x):
        # Check if we are working with dialog units
        value = self.text.GetValue()
        units = ''
        if value[-1].upper() == 'D':
            units = value[-1]
            value = value[:-1]
        try:
            intValue = int(value) + x
            self.spin.SetValue(intValue)
            self.text.SetValue(str(intValue) + units)
            self.SetModified()
        except:
            # !!! Strange, if I use wxLogWarning, event is re-generated
            print 'incorrect unit format'
    def OnSpinUp(self, evt):
        self.Change(1)
    def OnSpinDown(self, evt):
        self.Change(-1)

class ParamText(PPanel):
    def __init__(self, parent, name, textWidth=-1):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        # We use sizer even here to have the same size of text control
        sizer = wxBoxSizer()
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=wxSize(textWidth,-1))
        if textWidth == -1: option = 1
        else: option = 0
        sizer.Add(self.text, option, wxALIGN_CENTER_VERTICAL)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        EVT_TEXT(self, self.ID_TEXT_CTRL, self.OnChange)
    def GetValue(self):
        return self.text.GetValue()
    def SetValue(self, value):
        self.freeze = True              # disable other handlers
        self.text.SetValue(value)
        self.freeze = False             # disable other handlers

class ParamAccel(ParamText):
    def __init__(self, parent, name):
        ParamText.__init__(self, parent, name, 100)

class ParamPosSize(ParamText):
    def __init__(self, parent, name):
        ParamText.__init__(self, parent, name, 80)

class ParamLabel(ParamText):
    def __init__(self, parent, name):
        ParamText.__init__(self, parent, name, 200)

class ParamEncoding(ParamText):
    def __init__(self, parent, name):
        ParamText.__init__(self, parent, name, 100)

class ContentDialog(wxDialogPtr):
    def __init__(self, parent, value):
        # Load from resource
        w = g.frame.res.LoadDialog(parent, 'DIALOG_CONTENT')
        # Perform initialization with class pointer
        wxDialogPtr.__init__(self, w.this)
        self.thisown = 1
        self.Center()
        self.list = self.FindWindowByName('LIST')
        # Set list items
        for v in value:
            self.list.Append(v)
        self.SetAutoLayout(True)
        self.GetSizer().Fit(self)
        # Callbacks
        self.ID_BUTTON_APPEND = XMLID('BUTTON_APPEND')
        self.ID_BUTTON_REMOVE = XMLID('BUTTON_REMOVE')
        self.ID_BUTTON_UP = XMLID('BUTTON_UP')
        self.ID_BUTTON_DOWN = XMLID('BUTTON_DOWN')
        EVT_BUTTON(self, self.ID_BUTTON_UP, self.OnButtonUp)
        EVT_BUTTON(self, self.ID_BUTTON_DOWN, self.OnButtonDown)
        EVT_BUTTON(self, self.ID_BUTTON_APPEND, self.OnButtonAppend)
        EVT_BUTTON(self, self.ID_BUTTON_REMOVE, self.OnButtonRemove)
        EVT_UPDATE_UI(self, self.ID_BUTTON_UP, self.OnUpdateUI)
        EVT_UPDATE_UI(self, self.ID_BUTTON_DOWN, self.OnUpdateUI)
        EVT_UPDATE_UI(self, self.ID_BUTTON_REMOVE, self.OnUpdateUI)
    def OnButtonUp(self, evt):
        i = self.list.GetSelection()
        str = self.list.GetString(i)
        self.list.Delete(i)
        self.list.InsertItems([str], i-1)
        self.list.SetSelection(i-1)
    def OnButtonDown(self, evt):
        i = self.list.GetSelection()
        str = self.list.GetString(i)
        self.list.Delete(i)
        self.list.InsertItems([str], i+1)
        self.list.SetSelection(i+1)
    def OnButtonAppend(self, evt):
        str = wxGetTextFromUser('Enter new item:', 'Append', '', self)
        self.list.Append(str)
    def OnButtonRemove(self, evt):
        self.list.Delete(self.list.GetSelection())
    def OnUpdateUI(self, evt):
        if evt.GetId() == self.ID_BUTTON_REMOVE:
            evt.Enable(self.list.GetSelection() != -1)
        elif evt.GetId() == self.ID_BUTTON_UP:
            evt.Enable(self.list.GetSelection() > 0)
        elif evt.GetId() == self.ID_BUTTON_DOWN:
            evt.Enable(self.list.GetSelection() != -1 and \
                       self.list.GetSelection() < self.list.Number() - 1)

class ContentCheckListDialog(wxDialogPtr):
    def __init__(self, parent, value):
        w = g.frame.res.LoadDialog(parent, 'DIALOG_CONTENT_CHECK_LIST')
        wxDialogPtr.__init__(self, w.this)
        self.thisown = 1
        self.Center()
        self.list = self.FindWindowByName('CHECK_LIST')
        # Set list items
        i = 0
        for v,ch in value:
            self.list.Append(v)
            self.list.Check(i, ch)
            i += 1
        self.SetAutoLayout(True)
        self.GetSizer().Fit(self)
        # Callbacks
        self.ID_BUTTON_APPEND = XMLID('BUTTON_APPEND')
        self.ID_BUTTON_REMOVE = XMLID('BUTTON_REMOVE')
        self.ID_BUTTON_UP = XMLID('BUTTON_UP')
        self.ID_BUTTON_DOWN = XMLID('BUTTON_DOWN')
        EVT_CHECKLISTBOX(self, self.list.GetId(), self.OnCheck)
        EVT_BUTTON(self, self.ID_BUTTON_UP, self.OnButtonUp)
        EVT_BUTTON(self, self.ID_BUTTON_DOWN, self.OnButtonDown)
        EVT_BUTTON(self, self.ID_BUTTON_APPEND, self.OnButtonAppend)
        EVT_BUTTON(self, self.ID_BUTTON_REMOVE, self.OnButtonRemove)
        EVT_UPDATE_UI(self, self.ID_BUTTON_UP, self.OnUpdateUI)
        EVT_UPDATE_UI(self, self.ID_BUTTON_DOWN, self.OnUpdateUI)
        EVT_UPDATE_UI(self, self.ID_BUTTON_REMOVE, self.OnUpdateUI)
    def OnCheck(self, evt):
        # !!! Wrong wxGTK (wxMSW?) behavior: toggling selection if checking
        self.list.Deselect(evt.GetSelection())
    def OnButtonUp(self, evt):
        i = self.list.GetSelection()
        str, ch = self.list.GetString(i), self.list.IsChecked(i)
        self.list.Delete(i)
        self.list.InsertItems([str], i-1)
        self.list.Check(i-1, ch)
        self.list.SetSelection(i-1)
    def OnButtonDown(self, evt):
        i = self.list.GetSelection()
        str, ch = self.list.GetString(i), self.list.IsChecked(i)
        self.list.Delete(i)
        self.list.InsertItems([str], i+1)
        self.list.Check(i+1, ch)
        self.list.SetSelection(i+1)
    def OnButtonAppend(self, evt):
        str = wxGetTextFromUser('Enter new item:', 'Append', '', self)
        self.list.Append(str)
    def OnButtonRemove(self, evt):
        self.list.Delete(self.list.GetSelection())
    def OnUpdateUI(self, evt):
        if evt.GetId() == self.ID_BUTTON_REMOVE:
            evt.Enable(self.list.GetSelection() != -1)
        elif evt.GetId() == self.ID_BUTTON_UP:
            evt.Enable(self.list.GetSelection() > 0)
        elif evt.GetId() == self.ID_BUTTON_DOWN:
            evt.Enable(self.list.GetSelection() != -1 and \
                       self.list.GetSelection() < self.list.Number() - 1)

class ParamContent(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        self.ID_BUTTON_EDIT = wxNewId()
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer = wxBoxSizer()
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=wxSize(200,-1))
        sizer.Add(self.text, 0, wxRIGHT | wxALIGN_CENTER_VERTICAL, 5)
        self.button = wxButton(self, self.ID_BUTTON_EDIT, 'Edit...', size=buttonSize)
        sizer.Add(self.button, 0, wxALIGN_CENTER_VERTICAL)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        self.textModified = False
        EVT_BUTTON(self, self.ID_BUTTON_EDIT, self.OnButtonEdit)
        EVT_TEXT(self, self.ID_TEXT_CTRL, self.OnChange)
    def OnChange(self, evt):
        PPanel.OnChange(self, evt)
        self.textModified = True
    def GetValue(self):
        if self.textModified:           # text has newer value
            try:
                return eval(self.text.GetValue())
            except SyntaxError:
                wxLogError('Syntax error in parameter value: ' + self.GetName())
                return []
        return self.value
    def SetValue(self, value):
        self.freeze = True
        if not value: value = []
        self.value = value
        self.text.SetValue(str(value))  # update text ctrl
        self.freeze = False
    def OnButtonEdit(self, evt):
        if self.textModified:           # text has newer value
            try:
                self.value = eval(self.text.GetValue())
            except SyntaxError:
                wxLogError('Syntax error in parameter value: ' + self.GetName())
                self.value = []
        dlg = ContentDialog(self, self.value)
        if dlg.ShowModal() == wxID_OK:
            value = []
            for i in range(dlg.list.Number()):
                value.append(dlg.list.GetString(i))
            # Add ignored flags
            self.SetValue(value)
            self.SetModified()
            self.textModified = False
        dlg.Destroy()

# CheckList content
class ParamContentCheckList(ParamContent):
    def __init__(self, parent, name):
        ParamContent.__init__(self, parent, name)
    def OnButtonEdit(self, evt):
        if self.textModified:           # text has newer value
            try:
                self.value = eval(self.text.GetValue())
            except SyntaxError:
                wxLogError('Syntax error in parameter value: ' + self.GetName())
                self.value = []
        dlg = ContentCheckListDialog(self, self.value)
        if dlg.ShowModal() == wxID_OK:
            value = []
            for i in range(dlg.list.Number()):
                value.append((dlg.list.GetString(i), dlg.list.IsChecked(i)))
            # Add ignored flags
            self.SetValue(value)
            self.SetModified()
            self.textModified = False
        dlg.Destroy()

class IntListDialog(wxDialogPtr):
    def __init__(self, parent, value):
        # Is this normal???
        w = g.frame.res.LoadDialog(parent, 'DIALOG_INTLIST')
        wxDialogPtr.__init__(self, w.this)
        self.thisown = 1
        self.Center()
        self.list = self.FindWindowByName('LIST')
        # Set list items
        value.sort()
        for v in value:
            if type(v) != IntType:
                wxLogError('Invalid item type')
            else:
                self.list.Append(str(v))
        self.SetAutoLayout(True)
        self.GetSizer().Fit(self)
        # Callbacks
        self.ID_BUTTON_ADD = XMLID('BUTTON_ADD')
        self.ID_BUTTON_REMOVE = XMLID('BUTTON_REMOVE')
        EVT_BUTTON(self, self.ID_BUTTON_ADD, self.OnButtonAppend)
        EVT_BUTTON(self, self.ID_BUTTON_REMOVE, self.OnButtonRemove)
        EVT_UPDATE_UI(self, self.ID_BUTTON_REMOVE, self.OnUpdateUI)
    def OnButtonAppend(self, evt):
        s = wxGetTextFromUser('Enter new number:', 'Add', '', self)
        # Check that it's unique
        try:
            v = int(s)
            s = str(v)                  # to be sure
            i = self.list.FindString(s)
            if i == -1:                 # ignore non-unique
                # Find place to insert
                found = False
                for i in range(self.list.Number()):
                    if int(self.list.GetString(i)) > v:
                        found = True
                        break
                if found: self.list.InsertItems([s], i)
                else: self.list.Append(s)
        except ValueError:
            wxLogError('List item is not an int!')
    def OnButtonRemove(self, evt):
        self.list.Delete(self.list.GetSelection())
    def OnUpdateUI(self, evt):
        if evt.GetId() == self.ID_BUTTON_REMOVE:
            evt.Enable(self.list.GetSelection() != -1)

# For growable list
class ParamIntList(ParamContent):
    def __init__(self, parent, name):
        ParamContent.__init__(self, parent, name)
    def OnButtonEdit(self, evt):
        if self.textModified:           # text has newer value
            try:
                self.value = eval(self.text.GetValue())
            except SyntaxError:
                wxLogError('Syntax error in parameter value: ' + self.GetName())
                self.value = []
        dlg = IntListDialog(self, self.value)
        if dlg.ShowModal() == wxID_OK:
            value = []
            for i in range(dlg.list.Number()):
                value.append(int(dlg.list.GetString(i)))
            # Add ignored flags
            self.SetValue(value)
            self.SetModified()
            self.textModified = False
        dlg.Destroy()

# Boxless radiobox
class RadioBox(PPanel):
    def __init__(self, parent, id, choices,
                 pos=wxDefaultPosition, name='radiobox'):
        PPanel.__init__(self, parent, name)
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        self.choices = choices
        topSizer = wxBoxSizer()
        for i in choices:
            button = wxRadioButton(self, -1, i, name=i)
            topSizer.Add(button)
            EVT_RADIOBUTTON(self, button.GetId(), self.OnRadioChoice)
        self.SetAutoLayout(True)
        self.SetSizer(topSizer)
        topSizer.Fit(self)
    def SetStringSelection(self, value):
        self.freeze = True
        for i in self.choices:
            self.FindWindowByName(i).SetValue(i == value)
        self.value = value
        self.freeze = False
    def OnRadioChoice(self, evt):
        if self.freeze: return
        if evt.GetSelection():
            self.value = evt.GetEventObject().GetName()
            self.SetModified()
    def GetStringSelection(self):
        return self.value

class ParamBool(RadioBox):
    values = {'yes': '1', 'no': '0'}
    seulav = {'1': 'yes', '0': 'no'}
    def __init__(self, parent, name):
        RadioBox.__init__(self, parent, -1, choices = self.values.keys(), name=name)
    def GetValue(self):
        return self.values[self.GetStringSelection()]
    def SetValue(self, value):
        if not value: value = '1'
        self.SetStringSelection(self.seulav[value])

class ParamOrient(RadioBox):
    values = {'horizontal': 'wxHORIZONTAL', 'vertical': 'wxVERTICAL'}
    seulav = {'wxHORIZONTAL': 'horizontal', 'wxVERTICAL': 'vertical'}
    def __init__(self, parent, name):
        RadioBox.__init__(self, parent, -1, choices = self.values.keys(), name=name)
    def GetValue(self):
        return self.values[self.GetStringSelection()]
    def SetValue(self, value):
        if not value: value = 'wxHORIZONTAL'
        self.SetStringSelection(self.seulav[value])

class ParamFile(PPanel):
    def __init__(self, parent, name):
        PPanel.__init__(self, parent, name)
        self.ID_TEXT_CTRL = wxNewId()
        self.ID_BUTTON_BROWSE = wxNewId()
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        sizer = wxBoxSizer()
        self.text = wxTextCtrl(self, self.ID_TEXT_CTRL, size=wxSize(200,-1))
        sizer.Add(self.text, 0, wxRIGHT | wxALIGN_CENTER_VERTICAL, 5)
        self.button = wxButton(self, self.ID_BUTTON_BROWSE, 'Browse...',size=buttonSize)
        sizer.Add(self.button, 0, wxALIGN_CENTER_VERTICAL)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)
        self.textModified = False
        EVT_BUTTON(self, self.ID_BUTTON_BROWSE, self.OnButtonBrowse)
        EVT_TEXT(self, self.ID_TEXT_CTRL, self.OnChange)
    def OnChange(self, evt):
        PPanel.OnChange(self, evt)
        self.textModified = True
    def GetValue(self):
        if self.textModified:           # text has newer value
            return self.text.GetValue()
        return self.value
    def SetValue(self, value):
        self.freeze = True
        self.value = value
        self.text.SetValue(value)  # update text ctrl
        self.freeze = False
    def OnButtonBrowse(self, evt):
        if self.textModified:           # text has newer value
            self.value = self.text.GetValue()
        dlg = wxFileDialog(self,
                           defaultDir = os.path.abspath(os.path.dirname(self.value)),
                           defaultFile = os.path.basename(self.value))
        if dlg.ShowModal() == wxID_OK:
            # Get common part of selected path and current
            if g.frame.dataFile:
                curpath = os.path.abspath(g.frame.dataFile)
            else:
                curpath = os.path.join(os.getcwd(), '')
            common = os.path.commonprefix([curpath, dlg.GetPath()])
            self.SetValue(dlg.GetPath()[len(common):])
            self.SetModified()
            self.textModified = False
        dlg.Destroy()

class ParamBitmap(PPanel):
    def __init__(self, parent, name):
        # Load from resource
        w = g.frame.res.LoadPanel(parent, 'PANEL_BITMAP')
        # Perform initialization with class pointer
        wxPanelPtr.__init__(self, w.this)
        self.thisown = 1
        self.modified = self.freeze = False
        self.SetBackgroundColour(g.panel.GetBackgroundColour())
        self.radio_std = self.FindWindowByName('RADIO_STD')
        self.radio_file = self.FindWindowByName('RADIO_FILE')
        self.combo = self.FindWindowByName('COMBO_STD')
        self.text = self.FindWindowByName('TEXT_FILE')
        self.button = self.FindWindowByName('BUTTON_BROWSE')
        self.textModified = False
        self.SetAutoLayout(True)
        self.GetSizer().SetMinSize((260, -1))
        self.GetSizer().Fit(self)
        EVT_RADIOBUTTON(self, XMLID('RADIO_STD'), self.OnRadioStd)
        EVT_RADIOBUTTON(self, XMLID('RADIO_FILE'), self.OnRadioFile)
        EVT_BUTTON(self, XMLID('BUTTON_BROWSE'), self.OnButtonBrowse)
        EVT_COMBOBOX(self, XMLID('COMBO_STD'), self.OnCombo)
        EVT_TEXT(self, XMLID('COMBO_STD'), self.OnChange)
        EVT_TEXT(self, XMLID('TEXT_FILE'), self.OnChange)
    def OnRadioStd(self, evt):
        self.SetModified()
        self.SetValue(['wxART_MISSING_IMAGE',''])
    def OnRadioFile(self, evt):
        self.SetModified()
        self.SetValue(['',''])
    def updateRadios(self):
        if self.value[0]:
            self.radio_std.SetValue(True)
            self.text.Enable(False)
            self.button.Enable(False)
            self.combo.Enable(True)
        else:
            self.radio_file.SetValue(True)
            self.text.Enable(True)
            self.button.Enable(True)
            self.combo.Enable(False)
    def OnChange(self, evt):
        PPanel.OnChange(self, evt)
        self.textModified = True
    def OnCombo(self, evt):
        PPanel.OnChange(self, evt)
        self.value[0] = self.combo.GetValue()
    def GetValue(self):
        if self.textModified:           # text has newer value
            return [self.combo.GetValue(), self.text.GetValue()]
        return self.value
    def SetValue(self, value):
        self.freeze = True
        if not value:
            self.value = ['', '']
        else:
            self.value = value
        self.combo.SetValue(self.value[0])
        self.text.SetValue(self.value[1])  # update text ctrl
        self.updateRadios()
        self.freeze = False
    def OnButtonBrowse(self, evt):
        if self.textModified:           # text has newer value
            self.value[1] = self.text.GetValue()
        dlg = wxFileDialog(self,
                           defaultDir = os.path.abspath(os.path.dirname(self.value[1])),
                           defaultFile = os.path.basename(self.value[1]))
        if dlg.ShowModal() == wxID_OK:
            # Get common part of selected path and current
            if g.frame.dataFile:
                curpath = os.path.abspath(g.frame.dataFile)
            else:
                curpath = os.path.join(os.getcwd(), '')
            common = os.path.commonprefix([curpath, dlg.GetPath()])
            self.SetValue(['', dlg.GetPath()[len(common):]])
            self.SetModified()
            self.textModified = False
        dlg.Destroy()

paramDict = {
    'flag': ParamFlag,
    'style': ParamStyle, 'exstyle': ParamExStyle,
    'pos': ParamPosSize, 'size': ParamPosSize,
    'border': ParamUnit, 'cols': ParamInt, 'rows': ParamInt,
    'vgap': ParamUnit, 'hgap': ParamUnit,
    'checkable': ParamBool, 'checked': ParamBool, 'radio': ParamBool,
    'accel': ParamAccel,
    'label': ParamText, 'title': ParamText, 'value': ParamText,
    'content': ParamContent, 'selection': ParamInt,
    'min': ParamInt, 'max': ParamInt,
    'fg': ParamColour, 'bg': ParamColour, 'font': ParamFont,
    'enabled': ParamBool, 'focused': ParamBool, 'hidden': ParamBool,
    'tooltip': ParamText, 'bitmap': ParamBitmap, 'icon': ParamBitmap,
    'label': ParamLabel, 'encoding': ParamEncoding
    }



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: App.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import EvtHandler
import Parameters as wx

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class PyApp(EvtHandler):
    """Python Application base class.

    It is used to:

    - set and get application-wide properties;

    - implement the windowing system message or event loop;

    - initiate application processing via App.OnInit;

    - allow default processing of events not handled by other objects
      in the application."""

    def __init__(self):
        """Create a PyApp instance."""
        pass

    def Dispatch(self):
        """Dispatches the next event in the windowing system event
        queue.

        This can be used for programming event loops."""
        pass

    def ExitMainLoop(self):
        """Call this to explicitly exit the main message (event) loop.

        You should normally exit the main loop (and the application)
        by deleting the top window, which wxPython does automatically."""
        pass

    def GetAppName(self):
        """Return the application name."""
        pass

    def GetAssertMode(self):
        """Return the current assertion mode."""
        pass

    def GetAuto3D(self):
        """Returns True if 3D control mode is on, False otherwise.
        Windows only."""
        pass

    def GetClassName(self):
        """Return the class name of the application."""
        pass

    def GetExitOnFrameDelete(self):
        """Returns True if the application will exit when the
        top-level window is deleted, False otherwise."""
        pass

    def GetPrintMode(self):
        """Deprecated."""
        pass

    def GetTopWindow(self):
        """Return the top window.

        If the top window hasn't been set using App.SetTopWindow,
        this method will find the first top-level window (frame or
        dialog) and return that."""
        pass

    def GetUseBestVisual(self):
        """Return True if the application will use the best visual on
        systems that support different visuals, False otherwise."""
        pass

    def GetVendorName(self):
        """Return the application's vendor name."""
        pass

    def Initialized(self):
        """Return True if the application has been initialized
        (i.e. if App.OnInit has returned successfully). This can be
        useful for error message routines to determine which method of
        output is best for the current state of the program (some
        windowing systems may not like dialogs to pop up before the
        main loop has been entered)."""
        pass

    def MainLoop(self):
        """Called by wxWindows on creation of the application.
        Override this if you wish to provide your own
        (environment-dependent) main loop.

        Return 0 under X, and the wParam of the WM_QUIT message under
        Windows."""
        pass

    def OnAssert(self, file, line, cond, msg):
        """Called when an assert failure occurs, i.e. the condition
        specified in ASSERT macro evaluated to FALSE. It is only
        called in debug mode (when __WXDEBUG__ is defined) as asserts
        are not left in the release code at all.

        The base class version show the default assert failure dialog
        box proposing to the user to stop the program, continue or
        ignore all subsequent asserts.

        file is the name of the source file where the assert occured

        line is the line number in this file where the assert occured

        cond is the condition of the failed assert in string form

        msg is the message specified as argument to ASSERT_MSG or
        FAIL_MSG, will be NULL if just ASSERT or FAIL was used"""
        pass

    def OnExit(self):
        """Provide this member function for any processing which needs
        to be done as the application is about to exit.  OnExit is
        called after destroying all application windows and controls,
        but before wxWindows cleanup."""
        pass

    def OnInit(self):
        """This must be provided by the application, and will usually
        create the application's main window, optionally calling
        App.SetTopWindow.

        Return True to continue processing, False to exit the
        application."""
        pass

    def OnInitGui(self):
        """Called just after the platform's GUI has been initialized,
        but before the App.OnInit() gets called. Rarely needed in
        practice. Unlike App.OnInit(), does not need to return
        True/False."""
        pass
    
    def Pending(self):
        """Return True if unprocessed events are in the window system
        event queue."""
        pass

    def ProcessIdle(self):
        """Sends the EVT_IDLE event and is called inside the MainLoop.
        
        You only need this if you implement your own main loop."""
        pass

    def SetAppName(self, name):
        """Set the name of the application."""
        pass

    def SetAssertMode(self, mode):
        """Lets you control how C++ assertions are processed.

        Valid modes are: PYAPP_ASSERT_SUPPRESS,
        PYAPP_ASSERT_EXCEPTION, and PYAPP_ASSERT_DIALOG.  Using
        _SUPPRESS will give you behavior like the old final builds and
        the assert will be ignored, _EXCEPTION is the new default
        described above, and _DIALOG is like the default in 2.3.3.1
        and prior hybrid builds.  You can also combine _EXCEPTION and
        _DIALOG if you wish, although I don't know why you would."""
        pass

    def SetAuto3D(self, auto3D):
        """Switches automatic 3D controls on or off.  Windows only.

        If auto3D is True, all controls will be created with 3D
        appearances unless overridden for a control or dialog.  The
        default is True."""
        pass

    def SetClassName(self, name):
        """Set the class name of the application."""
        pass

    def SetExitOnFrameDelete(self, flag):
        """If flag is True (the default), the application will exit
        when the top-level frame is deleted.  If False, the
        application will continue to run."""
        pass

    def SetPrintMode(self, mode):
        """Deprecated."""
        pass

    def SetTopWindow(self, window):
        """Set the 'top' window.

        You can call this from within App.OnInit to let wxWindows
        know which is the main window.  You don't have to set the top
        window; it is only a convenience so that (for example) certain
        dialogs without parents can use a specific window as the top
        window.  If no top window is specified by the application,
        wxWindows just uses the first frame or dialog in its top-level
        window list, when it needs to use the top window."""
        pass

    def SetUseBestVisual(self, flag):
        """Allows the programmer to specify whether the application
        will use the best visual on systems that support several
        visual on the same display.  This is typically the case under
        Solaris and IRIX, where the default visual is only 8-bit
        whereas certain applications are supposed to run in TrueColour
        mode.

        Note that this function has to be called in the constructor of
        the App instance and won't have any effect when called later
        on.

        This function currently only has effect under GTK."""
        pass

    def SetVendorName(self, name):
        """Sets the name of application's vendor.  The name will be
        used in registry access."""
        pass

    def Yield(self, onlyIfNeeded=False):
        """Yields control to pending messages in the windowing system.
        This can be useful, for example, when a time-consuming process
        writes to a text window.  Without an occasional yield, the
        text window will not be updated properly, and on systems with
        cooperative multitasking, such as Windows 3.1 other processes
        will not respond.

        Caution should be exercised, however, since yielding may allow
        the user to perform actions which are not compatible with the
        current task.  Disabling menu items or whole menus during
        processing can avoid unwanted reentrance of code: see
        wx.SafeYield for a better function.

        Calling Yield() recursively is normally an error and an assert
        failure is raised in debug build if such situation is
        detected.  However if the the onlyIfNeeded parameter is True,
        the method will just silently return False instead."""
        pass


from wxPython.wx import wxPlatform
_redirect = (wxPlatform == '__WXMSW__' or wxPlatform == '__WXMAC__')
del wxPlatform


class App(PyApp):
    """The main application class.

    Inherit from this class and implement an OnInit method that
    creates a frame and then calls self.SetTopWindow(frame)."""

    def __init__(self, redirect=_redirect, filename=None, useBestVisual=False):
        """Create an App instance.

        redirect defaults to True on Windows and Mac. If redirect is
        True, stdio goes to an output window or a file if filename is
        not None."""
        pass


del _redirect


class PyOnDemandOutputWindow:
    """Used by App to display stdout and stderr messages if app is
    created using App(redirect=True).  Mostly useful on Windows or
    Mac where apps aren't always launched from the command line."""
    pass


class PySimpleApp(App):
    """Use instead of App for simple apps with a simple frame or
    dialog, particularly for testing."""

    def __init__(self, flag=0):
        """Create a PySimpleApp instance.

        flag is the same as App's redirect parameter to redirect stdio."""
        pass

    def OnInit(self):
        """Automatically does a wx.InitAllImageHandlers()."""
        pass


class PyWidgetTester(App):
    """Use instead of App for testing widgets. Provides a frame
    containing an instance of a widget.

    Create a PyWidgetTester instance with the desired size for the
    frame, then create the widget and show the frame using SetWidget."""

    def __init__(self, size=(250, 100)):
        """Create a PyWidgetTester instance, with no stdio redirection.

        size is for the frame to hold the widget."""
        pass

    def OnInit(self):
        """Creates a frame that will hold the widget to be tested."""
        pass

    def SetWidget(self, widgetClass, *args):
        """Create a widgetClass instance using the supplied args and
        with a frame as parent, then show the frame."""
        pass


class SingleInstanceChecker:
    """Allows one to check that only a single instance of a program is
    running. To do it, you should create an object of this class. As
    long as this object is alive, calls to IsAnotherRunning() from
    other processes will return True.

    As the object should have the life span as big as possible, it
    makes sense to create it either as a global or in App.OnInit()."""

    def __init__(self, name, path=wx.EmptyString):
        """Create a SingleInstanceChecker instance.

        name should be as unique as possible. It is used as the mutex
        name under Win32 and the lock file name under Unix.
        App.GetAppName() and wx.GetUserId() are commonly used.

        path is optional and is ignored under Win32 and used as the
        directory to create the lock file in under Unix (default is
        wx.GetHomeDir())."""
        pass

    def Create(self, name, path=wx.EmptyString):
        """Create a SingleInstanceChecker instance."""
        pass

    def IsAnotherRunning(self):
        """Return True if another copy of this program is already running."""
        pass
